@@ -819,7 +819,6 @@ thunar_properties_dialog_icon_button_clicked (GtkWidget              *button,
                                          _("_Cancel"), GTK_RESPONSE_CANCEL,
                                          _("_OK"), GTK_RESPONSE_ACCEPT,
                                          NULL);
-  gtk_dialog_set_alternative_button_order (GTK_DIALOG (chooser), GTK_RESPONSE_ACCEPT, GTK_RESPONSE_CANCEL, -1);
   gtk_dialog_set_default_response (GTK_DIALOG (chooser), GTK_RESPONSE_ACCEPT);
   g_free (title);
 
@@ -1430,7 +1429,7 @@ thunar_properties_dialog_set_files (ThunarPropertiesDialog *dialog,
   for (lp = dialog->files; lp != NULL; lp = lp->next)
     {
       _thunar_assert (THUNAR_IS_FILE (lp->data));
-      file = g_object_ref (G_OBJECT (lp->data));
+      file = THUNAR_FILE (g_object_ref (G_OBJECT (lp->data)));
 
       /* watch the file for changes */
       thunar_file_watch (file);
